pub struct AssetsProof { /* fields omitted */ }
A receipt containing the aggregate balance of a VASP and all of its child VASP
accounts, in addition to each individual account’s balance and on-chain metadata.
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Generates a hash used only for tests.
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,