pub struct ParentVASPView { /* fields omitted */ }
A simplified view of the parent VASP account, ignoring irrelevant info like
the sent/receive event keys.
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
The type returned in the event of a conversion error.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Generates a hash used only for tests.
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,